<?php
/**
	 * dBeautifier_Admin Class
	 * This class contains all the admin pages, menus and things of
	 * that sort. Also hold the intial install function for this
	 * plugin.
	 * 
	 * Variables:
	 * 	$dB_sitePath 		[ String ; The user set sitepath ]
	 *  $dB_displayName 	[ Bool ; Option to display the filename in the download ]
	 *  $dB_displaySize		[ Bool ; Option to display the file size in the download ]
	 *  $dB_FileTypes		[ Array ; With file extension and there icon associations ]
	 * 
	 * Functions:
	 * 	dB_InitPages()		 [ Function to initalize the pages and also calls dB_getOptions() ]
	 *  dB_getOptions() 	 [ Function that pulls all of the options and reads them into the class varaibles ]
	 *  dB_Admin()			 [ Function that handles layout and option updates etc... in the WP Admin ]
	 *  dB_Installation()	 [ Function that preforms the initial install when the plugin in activated ]
	 *
	 */
	class dBeautifier_Admin {
		var $dB_sitePath;
		
		// Options
		var $dB_displayName;
		var $dB_displaySize;
		var $dB_displayDownloads;
		var $dB_Use;
		
		function dB_InitPages() {
			if (function_exists('add_options_page')) {
				add_options_page('dBeautifier', 'dBeautifier', 9, __FILE__, array(&$this, 'dB_Admin'));
			}
			
			// Grab any options
			dBeautifier_Admin::dB_getOptions();
		}
		
		function dB_getOptions() {
			// Load the options
			$this->dB_sitePath = get_option('dB_sitePath');
			$this->dB_displayName = get_option('dB_displayName');
			$this->dB_displaySize = get_option('dB_displaySize');
			$this->dB_displayDownloads = get_option('dB_displayDownloads');
			$this->dB_Use = get_option('dB_Use');
			
		}
		
		function dB_Admin() {
			global $wpdb, $table_prefix, $user_level;
			get_currentuserinfo();
			
			if ($user_level < 9) {
				_e('Not a hight enough user level.');
				die();
			}
			
			$dBFiletypes = $table_prefix . 'dBFiletypes';
			
			if (isset($_POST['addExt']) || isset($_POST['editExt'])) {
				// Add or Modify Assocations
				$wpdb->query("replace into $dBFiletypes (dBExt, dBIcon) values ('{$_POST['ext']}', '{$_POST['icon']}')");
				
				if (isset($_POST['editExt'])) {
					print "<div class='updated'><br /><strong>"; _e('File Extension Successfully Changed'); print "</strong><br />&nbsp;</div>";
				} else {
					print "<div class='updated'><br /><strong>"; _e('File Extension Successfully Added'); print "</strong><br />&nbsp;</div>";
				}
			} elseif (isset($_POST['updateOptions'])) {
				// Update General Options
				if (empty($_POST['displayName'])) { $_POST['displayName'] = 0; }
				if (empty($_POST['displaySize'])) { $_POST['displaySize'] = 0; }
				if (empty($_POST['displayDownloads'])) { $_POST['displayDownloads'] = 0; }
				
				update_option('dB_displayName', $_POST['displayName']);
				update_option('dB_displaySize', $_POST['displaySize']);
				update_option('dB_displayDownloads', $_POST['displayDownloads']);
				update_option('dB_sitePath', $_POST['sitePath']);
				update_option('dB_Use', $_POST['Use']);
				
				print "<div class='updated'><br /><strong>"; _e('Options Successfully Updated'); print "</strong><br />&nbsp;</div>";
				
			} elseif (isset($_POST['delId'])) {
				// Delete an association
				foreach ($_POST['ids'] as $id) {
					$wpdb->query("delete from $dBFiletypes where id = $id");
				}
				
				print "<div class='updated'><br /><strong>"; _e('File Extension(s) Successfully Deleted'); print "</strong><br />&nbsp;</div>";
			}
			
			// Get New Options
			dBeautifier_Admin::dB_getOptions();
			
			print "<div class='wrap'>
					<h2>dBeautifier</h2>
					<p>欢迎使用 Download Beautifier. 请确认您所配置的以下选项</p><br />
					<p><strong>用法: </strong><br />
					将下面简单的一段代码添加到您的文章就可以实现下载. 你可以认为这是一个HTML标记 
					&lt;download&gt;http://your.website.com;/path/to/your/download.ext;Your download description;&lt;/download&gt;
					注意在 &lt;download&gt 标记之间的参数要用 ; 来分割 <br />
					<br />
					<strong>举例说明:</strong><br />
					欢迎来到我的博客左铅右椠-上善若水. 我的网名叫bwskyer, 今天准备了变形金刚2的BT种子供大家下载, 请点击 &lt;download&gt;http://bwskyer.cn;/wp-content/files/bxjg.zip;变形金刚2&lt;/download&gt;. 解压下载即可. <br />
					<br />
					<h2>当前扩展名 </h2>
					
					<ul>
					<form action='' method='POST'>";
						$assoc = $wpdb->get_results("select id, dBExt, dBIcon from $dBFiletypes");
						foreach ($assoc as $asoc) {
							print "<li><input type='checkbox' name='ids[]' value='$asoc->id'> $asoc->dBExt => $asoc->dBIcon [ <a href='{$_SERVER['PHP_SELF']}?{$_SERVER['QUERY_STRING']}&edit=$asoc->id'>Edit</a> ]</li>";
						}
					
					print "</ul>
					<input type='submit' name='delId' value='删除所选'>
					</form>
					<br />
					<br />";
					
			if (isset($_GET['edit'])) {
				print "
					<h2>编辑文件扩展名</h2>
					<table width='70%'>
					<form action='' method='POST'>
					<tr>
						<td>文件扩展名 (记得带 .) </td>
						<td><input type='text' name='ext' size='5' value='{$_GET['edit']}'></td>
					</tr>
					<tr>
						<td>图标</td>
						<td><input type='text' name='icon' size='10' value='{$this->dB_FileTypes[$_GET['edit']]}'></td>
					</tr>
					<tr>
						<td colspan='2'><input type='submit' name='editExt' value='修改扩展名'></td>
					</tr>
					</form>
					</table>";
			} else {
				print "
					<h2>添加文件扩展名</h2>
					<table>
					<form action='' method='POST'>
					<tr>
						<td>文件扩展名 (记得带 .) </td>
						<td><input type='text' name='ext' size='5'> </td>
						<td>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;图标 </td>
						<td><select name='icon'>";
							
						dBeautifier_Admin::dB_pullFiles();						
							
						print "</select> (图标文件在: $this->dB_sitePath/wp-content/plugins/dBeautifier/icons/)</td>
					</tr>
					<tr>
						<td colspan='2'><input type='submit' name='addExt' value='添加扩展名'></td>
					</tr>
					</form>
					</table>";
				
			}
			
			print "<br />
			<h2>一般选项</h2>
			<table width='70%'>
			<form action='' method='POST'>
			<tr>
				<td>WordPress安装路径: </td>
				<td><input type='text' name='sitePath' value='$this->dB_sitePath'><br />";
			
				if (empty($this->dB_sitePath) || $this->dB_sitePath == '/you/need/to/set/this') {
					print "<span style='color: red;'>这个路径必须设置! 它就是wordpress安装路径 例如. /home/username/public_html/wp , 地址最后没有斜杠</span>";
				}
					
			print "</td>
				
			</tr>
			<tr>
				<td>显示文件名: </td>
				<td><input type='checkbox'" . dBeautifier_Admin::switchCheck($this->dB_displayName) . " name='displayName' value='1'></td>
			</tr>
			<tr>
				<td>显示文件大小: </td>
				<td><input type='checkbox'" . dBeautifier_Admin::switchCheck($this->dB_displaySize) . " name='displaySize' value='1'></td>
			</tr>
			<tr>
				<td>显示下载次数: </td>
				<td><input type='checkbox'" . dBeautifier_Admin::switchCheck($this->dB_displayDownloads) . " name='displayDownloads' value='1'></td>
			</tr>
			<tr>
				<td>页面刷新类型:</td>
				<td>PHP Header: <input type='radio' name='Use' value='Header'"; if ($this->dB_Use == 'Header') { print 'checked'; } print "/> <br />
					Javascript Refresh: <input type='radio' name='Use' value='Javascript'"; if ($this->dB_Use == 'Javascript') { print 'checked'; } print "/></td> 
			</tr>
			<tr>
				<td colspan='2'><input type='submit' name='updateOptions' value='Update Options'></td>
			</tr>
			</form>
			</table>
			
			</div>";
		}
		
		
		function switchCheck($value) {
			if ($value == 1 || $value == '1' || $value == "1") {
				return 'checked';
			}
		}
		
		/**
		 * dB_pullFiles() function.
		 * Looks for files, in the dBeautifier/icons directory
		 * and displays them in the drop down list. I didn't check
		 * for file extensions since there are many graphic extensions 
		 * and well I don't want to hunt them all down. So as a warning only
		 * put image files into the dBeautifier/icons directory.
		 * 
		 * Since we did a PHP 4 and 5 Version I can now use scandir :P
		 *
		 */
		function dB_pullFiles() {
			$path = $this->dB_sitePath . "/wp-content/plugins/dBeautifier/icons/";
			$fileArray = scandir($path);
			array_shift($fileArray);
			array_shift($fileArray);
			
			foreach ($fileArray as $file) {
				print "<option>$file</option>";
			}			
		}
		
		
		function dB_Installation() {
			global $wpdb, $table_prefix;
			
			$table_name1 = $table_prefix . 'dBFiletypes';
			$table_name2 = $table_prefix . 'dBClicks';
			
			if($wpdb->get_var("show tables like '$table_name1'") != $table_name1) {
				// setup dBFiletypes table
				$sql = "CREATE TABLE `$table_name1` (
						  `id` int(11) NOT NULL auto_increment,
						  `dBExt` varchar(5) NOT NULL default '',
						  `dBIcon` varchar(255) NOT NULL default '',
						  PRIMARY KEY  (`id`),
						  UNIQUE KEY `dBExt` (`dBExt`)
						);";
				
				require_once(ABSPATH . 'wp-admin/upgrade-functions.php');
      			dbDelta($sql);
      			
      			// add entrys to the table
      			$wpdb->query("insert into $table_name1 values (1, '.tar', 'tar.png'), (2, '.gz', 'tgz.png'), (3, '.zip', 'tar.png'), (4, '.rar', 'tar.png'), (5, '.pdf', 'pdf.png'), (6, '.doc', 'doc.png'), (7, '.txt', 'txt.png'), (8, '.c', 'source.png'), (9, '.cpp', 'source.png'), (10, '.pl', 'source.png'), (11, '.py', 'source.png'), (12, '.phps', 'source.png'), (13, '.sh', 'source.png'), (14, '.mp1', 'snd.png'), (15, '.mp2', 'snd.png'), (16, '.mp3', 'snd.png'), (17, '.wav', 'snd.png'), (18, '.midi', 'snd.png'), (19, '.snd', 'snd.png'), (20, '.avi', 'vid.png'), (21, '.mpg', 'vid.png'), (22, '.mpeg', 'vid.png'), (23, '.mov', 'vid.png'), (24, '.moov', 'vid.png'), (25, '.wmf', 'vid.png'), (26, '.divx', 'vid.png'), (27, '.asf', 'vid.png'), (28, '.mp4', 'vid.png'), (29, '.psd', 'img.png'), (30, '.gif', 'img.png'), (31, '.jpg', 'img.png'), (32, '.jpeg', 'img.png'), (33, '.tif', 'img.png'), (34, '.png', 'img.png'), (35, '.bmp', 'img.png'), (36, '.tiff', 'img.png');");
      			
			}
			
			if($wpdb->get_var("show tables like '$table_name2'") != $table_name2) {
				//setup dBClicks table
				$sql = "CREATE TABLE `$table_name2` (
						  `id` int(11) NOT NULL auto_increment,
						  `dBTime` int(11) NOT NULL default '0',
						  `dBIP` varchar(255) NOT NULL default '',
						  `dBFile` tinytext NOT NULL,
						  PRIMARY KEY  (`id`)
						);";
				
				require_once(ABSPATH . 'wp-admin/upgrade-functions.php');
      			dbDelta($sql);
			}
			
			
			// Add Needed Options
			add_option('dB_sitePath', '/you/need/to/set/this');
			add_option('dB_displayName', '0');
			add_option('dB_displaySize', '1');
			add_option('dB_displayDownloads', '1');
			add_option('dB_Use', 'Header');
		}	
	}
?>