<?php
	/**
	 * dBeautifier_Filter Calss
	 * This is the class that contains the actaul page work.
	 * By that I mean the filter is located here, and the section
	 * that builds the html.
	 * 
	 * Variables:
	 * 	$dB_sitePath 		[ String ; The user set sitepath ]
	 *  $dB_displayName 	[ Bool ; Option to display the filename in the download ]
	 *  $dB_displaySize		[ Bool ; Option to display the file size in the download ]
	 *  $dB_FileTypes		[ Array ; With file extension and there icon associations ]
	 * 
	 * Functions:
	 * 	__construct() 				 	[ Class Constructor ]
	 * 	dB_selectIcon(string $ext)	 	[ Funciton selects the icon based on its association in the array ]
	 * 	dB_buildHTML(array $data)	 	[ Function builds the html using the callbacks that where matched in the regular expression ]
	 * 	dB_Filter(string $content)	 	[ Function is the actaul filter that gets called by the 'the_content' hook ]
	 * 	dB_getFilesize(int $dsize)	 	[ Function calculates the size of a file ]
	 *  dB_getDownloads(string $file)	[ Function to get the number of downloads for the given file ]
	 * 	dB_CSS()					 	[ Function includes the CSS file int he 'wp_head' ]
	 *
	 */
	class dBeautifier_Filter {
		var $dB_sitePath;
		
		// Options
		var $dB_displayName;
		var $dB_displaySize;
		var $dB_displayDownloads;
		
		/**
		 * Initalization Function
		 */
		function __construct() {
			// Load the options
			$this->dB_sitePath = get_option('dB_sitePath');
			$this->dB_displayName = get_option('dB_displayName');
			$this->dB_displaySize = get_option('dB_displaySize');
			$this->dB_displayDownloads = get_option('dB_displayDownloads');
		}
		
		/**
		 * dB_selectIcon function
		 * This function selects the approperate icon based on its
		 * association in the array.
		 *
		 * @param string $ext
		 * @return string $img
		 */
		function dB_selectIcon($ext) {
			global $wpdb, $table_prefix;
			$dBFiletypes = $table_prefix . 'dBFiletypes';
			
			$icon = $wpdb->get_var("select dBIcon from $dBFiletypes where dBExt = '$ext'");
			if ($icon) {
				$img = get_option('siteurl') . "/wp-content/plugins/dBeautifier/icons/$icon";
			} else {
				$img = get_option('siteurl') . "/wp-content/plugins/dBeautifier/icons/downloads.png";
			}
			
			return $img;
		}
		
		/**
		 * dB_buildHTML function
		 * This function builds the html string for output.
		 * 
		 * @param array $data
		 * 		$data[0] => Entire Match
		 * 		$data[1] => URL to the file
		 * 		$data[2] => Site URL
		 * 		$data[3] => Path to the file
		 * 		$data[4] => File extension
		 * 		$data[5] => File link description
		 * 
		 * @return string $downloadLayout
		 */
		function dB_buildHTML($data) {
			if ($this->dB_displayDownloads == 1 || $this->dB_displayDownloads == '1') {
				$dls = "Downloads: " . dBeautifier_Filter::dB_getDownloads("{$data['2']}{$data['3']}");
			}
			
			if ($this->dB_displayName == 1 || $this->dB_displayName == '1') {
				$name = "File Name: " . dBeautifier_Filter::dB_parseFilename($data[3]);
			}
			
			if ($this->dB_displaySize == 1 || $this->dB_displaySize == '1') {
				$size = "File Size: " . dBeautifier_Filter::dB_getFilesize(@filesize($this->dB_sitePath . $data[3]));
			}
			
			$downloadLayout = "<div class='download-link'>
							<a href='" . get_option('siteurl') . "/download.php?file={$data[2]}{$data[3]}'><img alt='Download' class='leftalign' src='" . dBeautifier_Filter::dB_selectIcon($data[4]) . "' /></a>
							<h4>
								<a href='" . get_option('siteurl') . "/download.php?file={$data[2]}{$data[3]}'>{$data[5]}</a>
							</h4><p>$dls $size $name</p>
						</div>";
		
			return $downloadLayout;
		}
		
		/**
		 * dB_Filter function
		 * This functin gets called by the hook and actaully does the regex search for
		 * the [download][/download] tag
		 *
		 * @param string $content
		 * @return string $content
		 */
		function dB_Filter($content) {
			$content = preg_replace_callback('/<download>((.*);(.*(\\..*)));(.*);<\/download>/i', array($this, 'dB_buildHTML'), $content);
			return $content;
		}
		
		
		function dB_getDownloads($file) {
			global $wpdb, $table_prefix;
			$dBClicks = $table_prefix . 'dBClicks';
			
			$downloads = $wpdb->get_var("select count(id) from $dBClicks where dBFile = '$file'");
			
			return $downloads;
		}
		
		
		/**
		 * dB_getFilesize function
		 * This function caclulates a files size in nice
		 * human readable format.
		 *
		 * @param int $dsize
		 * @return string
		 */
		function dB_getFilesize ($dsize) {
			if (strlen($dsize) <= 9 && strlen($dsize) >= 7) {				
				$dsize = number_format($dsize / 1048576,1);
				return "$dsize MB";
			} elseif (strlen($dsize) >= 10) {
				$dsize = number_format($dsize / 1073741824,1);
				return "$dsize GB";
			} else {
				$dsize = number_format($dsize / 1024,1);
				return "$dsize KB";
			}
		}
		
		/**
		 * dB_parseFilename function
		 * This little baby just takes a string with the path to
		 * a file ie. /home/user/my/stuff/my/file.ext and turns it
		 * into file.ext. 
		 *
		 * @param string $string
		 * @return string
		 */
		function dB_parseFilename($string) {
			$filename = explode('/', $string);
			
			return $filename[count($filename) -1];
		}
		
		/**
		 * CSS Hook
		 */
		function dB_CSS() {
			print "<link rel=\"stylesheet\" type=\"text/css\" href=\"" . get_option('siteurl') . "/wp-content/plugins/dBeautifier/dBeautifier.css\" />";
		}
			
	}
?>